Param (
    [string]$loglevel = "info", # info or debug
	[string]$dnsDirectoryPrefix = "C://temp/", # Use the directory specified in the TrustView.groovy configuration file
	[string]$dnsDirectory = "msdns", # Subdirectory of the $dnsDirectoryPrefix (if none, leave empty)
	[string]$zoneName = "adtest.local", # Name of the DNS zone
    [int]$sleepTime = 60, # seconds
    [string]$processedDirectory = "C://temp/processed", # Directory to move processed DNS TXT records
    [string]$failedDirectory = "C://temp/failed" # Directory to move failed DNS TXT records
)

######################################################################
# TrustView Microsoft DNS Integration Script
#
# v1.0    2022-11-14
# v1.1    2023-05-25
# v1.2    2023-12-01
######################################################################

$Version = "1.2"

Function Write-DebugLog {
    param($msg)
    if ($loglevel -eq "debug") {
        Write-Host "$( Get-Date -Format G ) : $msg"
    }
}

Function Write-Log {
    param($msg)
    Write-Host "$( Get-Date -Format G ) : $msg"
}

While($true) {
    Get-ChildItem -Path "$dnsDirectoryPrefix\$dnsDirectory\" -Filter *.txt | Foreach-Object {
        $filePath = "$dnsDirectoryPrefix\$dnsDirectory\$_"
        Try {
            $dnsName = Get-Content -Path $filePath -First 1
            $dnsValue = Get-Content -Path $filePath -Tail 1
            Add-DnsServerResourceRecord -DescriptiveText $dnsValue -Name $dnsName -Txt -ZoneName $zoneName -TimeToLive 0:1:0:0
            Move-Item $filePath -Destination $processedDirectory
        } catch {
            Write-DebugLog $_.Exception.Message
            Move-Item $filePath -Destination $failedDirectory
        }
    }
    Start-Sleep -Seconds $sleepTime
}

Write-Log "Script completed successfully"
exit 0
