﻿# This script can assist when the Windows server containing TrustView and the DNS server, are
# not domain joined. It can be used for transfering DNS TXT records from TrustView
# (when using the 'filesystem' method with the DNS integration), to the DNS server and
# then using this script in combination with a scheduled task on the Windows server with TrustView,
# to transfer any DNS records from the C:\temp\ (default) directory to a designated directory on the DNS server.

Param (
    [string]$sourcePath = "C://temp/microsoftdns/*", # Path of the source, where TrustView has placed the DNS TXT records
    [string]$destinationPath = "\\192.168.1.1\trustviewDNS\txt", # Path of the destination, where the DNS TXT records should be copied to
    [string]$username = "username", # Username for network drive credentials
    [string]$password = "password" # Password for network drive credentials
)

######################################################################
# Transfer DNS Records Script
#
# v1.0    2023-06-09
# v1.1    2023-11-30
######################################################################

$Version = "1.1"

Set-ExecutionPolicy -ExecutionPolicy RemoteSigned

# Map the network drive using the provided credentials
net use $destinationPath /user:$username $password /persistent:yes

# Copy the files from the source to the destination and clean-up the files
Copy-Item -Path $sourcePath -Destination $destinationPath -recurse -Force
Remove-Item "$sourcePath\$_" -Force

# Remove the network drive mapping
net use $destinationPath /delete